Clojure only.

fmnoise.flow.macro


fletcljmacro

(flet bindings & body)

Flow adaptation of Clojure let. Wraps evaluation of each binding to call-with with default handler (defined with Catch.caught). If value returned from binding evaluation is failure, it's returned immediately and all other bindings and body are skipped.

Flow adaptation of Clojure `let`. Wraps evaluation of each binding to `call-with` with default handler (defined with `Catch.caught`). If value returned from binding evaluation is failure, it's returned immediately and all other bindings and body are skipped.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries