(flet bindings & body)Flow adaptation of Clojure let. Wraps evaluation of each binding to call-with with default handler (defined with Catch.caught). If value returned from binding evaluation is failure, it's returned immediately and all other bindings and body are skipped.
Flow adaptation of Clojure `let`. Wraps evaluation of each binding to `call-with` with default handler (defined with `Catch.caught`). If value returned from binding evaluation is failure, it's returned immediately and all other bindings and body are skipped.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |